@@ -132,10 +132,18 @@ class AsyncAPIClient(APIClientBase[httpx.AsyncClient]):
         url = self._build_url(path=path)
         return await self._request(Request(url=url, method="post", query_params=options.get("params"), body=options.get("body")), ResponseT=ResponseT)
 
+    async def put(self, path: str, options: RequestOptions = {}, ResponseT: type[ResponseT] = None):
+        url = self._build_url(path=path)
+        return await self._request(Request(url=url, method="put", body=options.get("body")), ResponseT=ResponseT)
+
     async def patch(self, path: str, options: RequestOptions = {}, ResponseT: type[ResponseT] = None):
         url = self._build_url(path=path)
         return await self._request(Request(url=url, method="patch", body=options.get("body")), ResponseT=ResponseT)
-
+    
+    async def delete(self, path: str, options: RequestOptions = {}, ResponseT: type[ResponseT] = None):
+        url = self._build_url(path=path)
+        return await self._request(Request(url=url, method="delete", query_params=options.get("params"), body=options.get("body")), ResponseT=ResponseT)
+    
     async def _request(self, request: Request, ResponseT: type[ResponseT]) -> Response[ResponseT]:
         http_request = self._build_request(request=request)
         try:
