@@ -1,9 +1,9 @@
 from ......_schemas import ApiDataModel
 from typing import TypeAlias
 from pydantic import Field
-from ....._schemas import Tag
+from ....._response_schemas import Tag
 
 class PutTagRequest(ApiDataModel):
     name: str = Field(description="Tag name")
 
-PutTagResponse: TypeAlias = Tag
\ No newline at end of file
+PutTagResponse: TypeAlias = list[Tag]
\ No newline at end of file
