@@ -13,7 +13,7 @@ class Stop(SyncAPIResourceBase):
         return f"workspaces/{self._workspace_id}/time_entries/{self._time_entry_id}"
 
     def patch(self) -> PatchStopResponse:
-        return self._client.patch(path=f"{self._path()}/stop", options={"params": {}, "body": {}}, ResponseT=PatchStopResponse)
+        return self._client.patch(path=f"{self._path()}/stop", options={"params": {}}, ResponseT=PatchStopResponse)
 
 
 class AsyncStop(AsyncAPIResourceBase):
